<?php namespace EscapeWork\Manager\Downloads\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Downloads\Repositories\DownloadCategory\DownloadCategoryRepository;
use EscapeWork\Manager\Downloads\Repositories\Download\DownloadRepository;
use EscapeWork\Manager\Downloads\Models\Download;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class DownloadsController extends ManagerController
{
    public function __construct(DownloadRepository $download, DownloadCategoryRepository $downloadCategory)
    {
        $this->download         = $download;
        $this->downloadCategory = $downloadCategory;

        # filters
        $this->enableDefaultFilters('downloads');
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $view = View::make('manager-downloads::downloads.index');
        $view->downloads = $this->download->paginate(20);
        return $view;
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $this->download->fill(Input::old());

        $view = View::make('manager-downloads::downloads.form');
        $view->downloadCategories = $this->downloadCategory->get();
        $view->download = $this->download;
        $view->edit  = false;

        return $view;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $this->download->fill(Input::all());

        if (! $this->download->validate()) {
            return Redirect::route('manager.downloads.create')
                        ->withInput()
                        ->with('errors', Download::$messages);
        }

        $this->download->file = $this->download->formatFileName(Input::file('file'));
        $this->download->uploadFile(Input::file('file'));
        $this->download->save();

        return Redirect::route('manager.downloads.index')->with('message', 'O  download<strong>' . $this->download->title . '</strong> foi inserido com sucesso!');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @return Response
     */
    public function edit($id)
    {
        $this->download = $this->download->findOrFail($id);

        Msg::setInfo('Editando o download <strong>' . $this->download->title . '</strong>');

        $view        = View::make('manager-downloads::downloads.form');
        $view->downloadCategories = $this->downloadCategory->get();
        $view->download = $this->download;
        $view->edit  = true;

        return $view;
    }

    /**
     *
     */
    public function update($id)
    {
        if (! $this->download = $this->download->find($id)) {
            return Redirect::route('manager.downloads.index')
                    ->with('error', 'Download não encontrado');
        }

        $fields = Input::except('_method');
        $this->download->fill($fields);

        if (! $this->download->validate()) {
            return Redirect::route('manager.downaloads.edit', array($this->download->id))
                    ->withInput()
                    ->with('errors', Download::$messages);
        }

        if(Input::hasFile('file')) {
            $this->download->file = $this->download->formatFileName(Input::file('file'));
            $this->download->uploadFile(Input::file('file'));
        }

        $this->download->save();

        return Redirect::route('manager.downloads.index')
                ->with('message', 'O download <strong>'.$this->download->title.'</strong> foi editado com sucesso!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (! $this->download = $this->download->find($id)) {
            return Redirect::route('manager.downloads.index')
                    ->with('error', 'Download não encontrado');
        }

        $this->download->deleteFile($this->download->file);
        $this->download->delete($id);

        return Redirect::route('manager.downloads.index')
                ->with('message', 'O download <strong>'.$this->download->title.'</strong> foi excluído com sucesso!');
    }
}
